#! /usr/bin/env node
/*
 * Copyright (c) 2019 Includable.
 * Created by Thomas Schoffelen.
 */

global.containerEndpoint = 'https://api.sandbox.includable.com/'
global.containerVersion = 11
global.apiStability = 'stable'
global.apiVersion = '1.0'
global.verbose = false
// noinspection JSUnresolvedVariable
global.base = __dirname

const program = require('commander')
const pkg = require('./package.json')
const commands = require('./lib/commands/index')

// Run in sandbox
program
  .command('run')
  .description('Run module in sandbox')
  .option('-e --environment [environment]', 'Environment to run in (user,manager,main)', /^(user|manager|main)$/)
  .option('-c --container [container]', 'Specify a custom container ID', /^[a-zA-Z0-9]{8,15}$/)
  .option('-r --recipe [recipe]', 'Use a JSON recipe file to create the container from template')
  .option('-b --beta', 'Enable beta API flag')
  .option('-s --silent', 'Don\'t open in web browser')
  .option('-v --verbose', 'Verbose logging')
  .action(commands.run)

// Login
program
  .command('login')
  .description('Sign in to your account')
  .option('--token', 'Output access token')
  .action(commands.login)

// Modules commands
program
  .command('publish [name]')
  .description('Publish new version of module')
  .action(commands.publish)
program
  .command('deploy <domain>')
  .description('Deploy the module on a specific domain')
  .action(commands.deploy)

// Reset
program
  .command('reset')
  .description('Reset container')
  .action(commands.reset)

// Help
program.addImplicitHelpCommand = function () {}
program
  .command('help', 'View this help section')
  .action(function () {
    program.help()
  })

// Download helper
program
  .command('helper:download')
  .description('Download IDE helper file')
  .action(commands.downloadHelper)

// Execute program
program
  .version('Includable CLI ' + pkg.version, '-V, --version')
  .parse(process.argv)

if (program.args.length === 0) {
  program.help()
  process.exit(1)
}
