/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

const FormData = require('form-data')
const fs = require('fs')
const axios = require('axios')

const API = require('../util/API')
const output = require('../output')
const runHelpers = require('../run-helpers')
const Module = require('../containers/Module')

const postRelease = function (moduleId, communityId) {
  const spinner = output.wait('Linking module to community')
  API.post('/communities/' + communityId + '/modules', { module: moduleId }).then(function () {
    spinner(true)
  })
}

const deployWithCommunity = function (communityId) {
  Module.getManifest(function (manifest) {
    if (!('name' in manifest) || !manifest.name || typeof manifest.name !== 'string' || !manifest.name.length) {
      output.err('Please set a valid value for key `name` in module.json')
      process.exit(1)
    }

    runHelpers.startChildProcess('build', function (error, exitCode) {
      if (error || exitCode > 0) {
        output.err('Build script exited with non-zero exit code, cancelling publish action')
        process.exit(1)
      }
      runHelpers.createZipArchive('.', 'Publish', function (zipFile, size, unlinkFn) {
        const spinner = output.wait(runHelpers.logSyncMessage('Uploading and building module (' + size + ')', true))

        const data = new FormData(null)
        data.append('file', fs.createReadStream(zipFile))
        axios.post('https://monkey.internal.includable.com/upload', data, { headers: data.getHeaders() })
          .then(function (response) {
            spinner(true)
            const spinner2 = output.wait(runHelpers.logSyncMessage('Creating deployment', true))
            API.post('/modules/publish', { registry_id: response.data.id })
              .then(function (response) {
                setTimeout(function () {
                  spinner2(true)
                  postRelease(response.data.data.module.id, communityId)
                }, 5000)
                unlinkFn()
              })
              .catch(function (response) {
                spinner2(response.response.data.error || 'Network error')
                unlinkFn()
                process.exit(1)
              })
          })
          .catch(function (response) {
            spinner(response.response.data.error || 'Network error')
            unlinkFn()
            process.exit(1)
          })
      })
    })
  })
}

module.exports = function (domain) {
  API.checkSignedIn()

  API.get('/communities/' + encodeURIComponent(domain)).then(function (response) {
    // Community already exists
    deployWithCommunity(response.data.data.id)
  }).catch(function () {
    // Community does not exist yet - create community
    const stopSpinner = output.wait('Creating new community ' + domain)
    API.post('/communities', { domain: domain }).then(function (response) {
      stopSpinner(true)
      deployWithCommunity(response.data.data.id)
    }).catch(function (err) {
      output.err(err)
    })
  })
}
