/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

'use strict'

const fs = require('fs')
const util = require('../util')
const Module = require('./Module')
const ContainerConfig = require('./ContainerConfig')

var Boxes = {}

/**
 * Create a new Includable cloud instance (dev mode).
 *
 * @param {RunOptions} options
 * @param {function(Error, BoxCreateResult)} callback
 */
Boxes.create = function (options, callback) {
  // First read module.json
  Module.getManifest(function (module) {
    // Create request
    var data = {
      'slug': module.slug
    }

    // Optionally add recipe
    if (options.recipe && options.recipe.length) {
      try {
        data.recipe = fs.createReadStream(options.recipe)
      } catch (e) {
        callback(new Error('Error reading recipe: ' + e.message), null)
        return
      }
    }

    // Send request
    util.request('create', data).end(function (response) {
      var result = response.body
      if (typeof result === 'string') {
        callback(new Error('Unexpected output: ' + result), null)
        return
      }
      if ('error' in result) {
        if (typeof result.error !== 'string' && 'description' in result.error) {
          result.error = result.error.description
        }
        callback(new Error(result.error), null)
        return
      }
      if (!('host' in result)) {
        callback(new Error('unknown error creating container'), null)
        return
      }

      ContainerConfig.write(options.beta ? 'beta' : 'default', {
        version: '1.0',
        containerToken: result.container_token,
        containerEndpoint: global.containerEndpoint,
        containerEndpointCheckSSL: process.env.NODE_TLS_REJECT_UNAUTHORIZED !== '0'
      })

      callback(null, result)
    })
  })
}

module.exports = Boxes
