/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

'use strict'

const path = require('path')
const fs = require('fs')

const ContainerConfig = require('./ContainerConfig')
const Boxes = require('./Boxes')

const Container = {}

/**
 * Get the version of the container metadata stored in the current directory (if any).
 *
 * @returns {int|boolean}
 */
Container.getVersion = function () {
  if (!fs.existsSync(path.join('.inc', 'version'))) {
    if (fs.existsSync('.scho' + 'lica')) {
      return 10
    }
    return false
  }

  return parseInt(fs.readFileSync(path.join('.inc', 'version'), 'utf8'), 10) || false
}

/**
 * Remove the default container config file.
 */
Container.clean = function () {
  try {
    fs.unlinkSync(path.join('.inc', 'containers', 'default.json'))
  } catch (e) {
    // Do nothing
  }
  try {
    fs.unlinkSync(path.join('.inc', 'containers', 'beta.json'))
  } catch (e) {
    // Do nothing
  }
}

/**
 * Read a container config file. If the file with the supplied container name doesn't exist,
 * this falls back to the 'default' container, if that one exists.
 *
 * @param {string} name
 * @param {function(Error, Object)} cb
 */
Container.getConfig = function (name, cb) {
  ContainerConfig.read(name, cb)
}

/**
 * Create a new Includable cloud instance (dev mode).
 *
 * @param {Object} options
 * @param {function(Error, Object)} callback
 */
Container.create = function (options, callback) {
  Boxes.create(options, callback)
}

module.exports = Container
