/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

'use strict'

const output = require('../output')
const path = require('path')
const jsonfile = require('jsonfile')
const createManifest = require('./ModuleManifest')

const Module = {}

/**
 * Get the manifest object for the module in the current directory.
 * @param {function(ModuleManifest)} callback
 * @param {string?} basePath
 */
Module.getManifest = function (callback, basePath) {
  const modulePath = basePath ? path.join(basePath, 'module.json') : 'module.json'
  jsonfile.readFile(modulePath, function (err, module) {
    if (err) {
      output.err('Error reading module.json: ' + err)
      process.exit(1)
    }
    if (!('slug' in module) || !module.slug || typeof module.slug !== 'string' || !module.slug.length) {
      output.err('Please set a valid value for module.slug')
      process.exit(1)
    }

    callback(createManifest(module))
  })
}

module.exports = Module
