/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

'use strict'

const minimatch = require('minimatch')
const _ = require('lodash')
const queryString = require('query-string')

const request = require('../util').request
const Module = require('../containers/Module')

const reload = _.debounce(function (containerToken, path, event) {
  request(containerToken + '/ws', {
    type: 'autoreload',
    payload: queryString.stringify({
      path: path,
      event: event
    })
  }).end()
}, 120)

const matchFile = function (options, path) {
  if (typeof options.paths === 'string') {
    options.paths = [options.paths]
  }

  for (var i in options.paths) {
    if (!options.paths.hasOwnProperty(i)) {
      continue
    }
    if (minimatch(path, options.paths[i])) {
      return true
    }
  }

  return false
}

module.exports = function (containerToken, path, event) {
  Module.getManifest(function (manifest) {
    var options = manifest.getDevOption('autoreload')
    if (options && typeof options === 'string') {
      options = {paths: [options]}
    }
    if (options && typeof options === 'object' && !('paths' in options) && 'length' in options) {
      options = {paths: options}
    }

    if (!options || typeof options !== 'object' || !('paths' in options)) {
      return
    }

    if (!matchFile(options, path)) {
      return
    }

    reload(containerToken, path, event)
  })
}
