/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

'use strict'

const path = require('path')
const fs = require('fs')
const mkdirp = require('mkdirp')
const axios = require('axios')

const output = require('./output')
const Request = require('./util/Request')

module.exports = {
  output: output,

  request: function (method, fields, headers, options) {
    return new Request(method, fields, headers, options)
  },

  statOrNothing: function (origPath, event, cb) {
    if (event !== 'add' && event !== 'change' && event !== 'change') {
      cb(null, true)
      return
    }

    fs.stat(origPath, function (err) {
      cb(null, event === 'unlink' ? !!err : !err)
    })
  },

  downloadHelper: function (cb, basepath, force) {
    // Determine path
    let helperBasePath = path.join('.inc', 'meta')
    if (basepath) {
      helperBasePath = path.join(basepath, helperBasePath)
    }
    const helperFilename = path.join(helperBasePath, '.phpstorm.meta.php')

    // Check last updated timestamp
    fs.stat(helperFilename, function (err, info) {
      if (!err && !force && info.mtime.getTime() > (new Date()).getTime() - 3600000) {
        cb && cb()
        return
      }

      // Download helper file
      axios.get(global.containerEndpoint + '/ide_helper').then((response) => {
        if (!response.data) {
          cb()
          return
        }
        mkdirp(helperBasePath, function () {
          fs.writeFile(helperFilename, response.data, 'utf8', () => cb && cb())
        })
      })
    })

    // Delete old helper file
    let oldHelperFilename = '._scho' + 'lica_ide_helper.php'
    if (basepath) {
      oldHelperFilename = path.join(basepath, oldHelperFilename)
    }
    try {
      fs.unlinkSync(oldHelperFilename)
    } catch (e) {}
  }

}
