/*
 * Copyright (c) 2018 Includable.
 * Created by Thomas Schoffelen.
 */

'use strict'

const output = require('../output')
const path = require('path')
const childProcess = require('shelljs')

const children = []

function killAll () {
  for (let child in children) {
    try {
      if (child) {
        child.kill('SIGINT')
      }
    } catch (e) {}
  }
}

function runProcess (script, callback, basePath) {
  const opts = {
    silent: true,
    async: true
  }
  if (basePath) {
    opts.cwd = path.resolve(basePath)
  }

  const process = childProcess.exec(script, opts)
  output.logComponent('Script', 'blue', 'Executing "' + script + '"')
  process.on('exit', function (code) {
    code = parseInt(code, 10) || code
    output.logComponent('Script', code === 0 ? 'blue' : 'red', 'Exited with code ' + code)
    if (callback) {
      callback(null, code)
    }
  })
  process.stderr.on('data', function (message) {
    output.logComponent('Script', 'red', message)
  })
  process.stdout.on('data', function (message) {
    output.logComponent('Script', 'blue', message)
  })

  children.push(process)
}

module.exports = {
  run: runProcess,
  killAll: killAll
}
